# Удаление приема

Можно удалить только открытые и не оплаченные приемы

**POST**: `https://api3.medelement.com/v2/doctor/reception/remove`

## Параметры:

| Название       | Тип    | Описание              |
| -------------- | ------ | --------------------- |
| reception_code | Bigint | Уникальный код приема |

## Ответ:

HTTP/1.1 200 OK

```json
[]
```
